@@ -1,6 +1,7 @@
+from .errors_types import ValidInput
 
 
-def get_input_as_string(src: str | int | list[int]) -> str:
+def get_input_as_string(src: ValidInput) -> str:
     if isinstance(src, str):
         return src
     if isinstance(src, int):
